"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.signal = exports.effect = void 0;
const createEffectsRegistry = () => {
    const registeredEffects = [];
    const notYetRegistered = (e) => !registeredEffects.some(r => r === e);
    return {
        runAll: (exclude = null) => registeredEffects.filter(r => r !== exclude).forEach(r => r.run()),
        register: (effect) => {
            if (effect && notYetRegistered(effect)) {
                registeredEffects.push(effect);
            }
        }
    };
};
let runningEffect = null;
function effect(component) {
    const s = {
        run() {
            runningEffect = this;
            const result = component();
            runningEffect = null;
            return result;
        }
    };
    return s.run();
}
exports.effect = effect;
function signal(initial) {
    const registry = createEffectsRegistry();
    var state = initial;
    return [
        function accessor() {
            registry.register(runningEffect);
            return state;
        },
        function setter(newState) {
            state = newState;
            registry.runAll(runningEffect);
        }
    ];
}
exports.signal = signal;
//# sourceMappingURL=reactivity.js.map